==> ecodev_front-0.0.36-py3-none-any.whl: ecodev_front/layouts/app_layout.py <==
"""
Base app component, utilising dmc.AppShell.
"""
import dash
import dash_mantine_components as dmc
from dash import dcc

from ecodev_front.ids import FOOTER_ID
from ecodev_front.ids import NAVBAR_ID
from ecodev_front.ids import TOKEN
from ecodev_front.ids import URL


def dash_base_layout(stores: list[tuple[str, str]],
                     colors: dict[str, list[str]] | None = None) -> dmc.MantineProvider:
    """
    Returns a base layout for any Dash application

    Parameters:
      - stores: A list of tuple (store_name/id, and dcc.Store memory type (https://dash.plotly.com/dash-core-components/store)). 
                The dcc.Store are placed in the root of the app, to ensure that they are accessible.
      - colors: A dictionary of color pallet name (key) and list of color values from 
                https://www.dash-mantine-components.com/components/mantineprovider#custom-colors
    """
    return dmc.MantineProvider(
        forceColorScheme='light',
        theme={'colors': colors} if colors else None,
        children=dmc.AppShell(
            [
                dcc.Location(id=URL, refresh=True),
                dcc.Store(id=TOKEN, data={TOKEN: None}, storage_type='local'),
                *[dcc.Store(id=store_id, storage_type=storage_type)
                  for store_id, storage_type in stores],
                dmc.AppShellHeader(id=NAVBAR_ID, children=[], style={'background-color': '#0066A1'}, zIndex=100),
                dmc.AppShellMain(dash.page_container, style={'margin-top': '2%'}),
                dmc.AppShellFooter(id=FOOTER_ID, children=[], zIndex=100),
            ],
            style={'padding-inline': '0px', 'background-color': '#f2f2f2'},
            header={'height': 55},
            footer={'height': 40},
        )
    )

==> ecodev_front-0.0.37-py3-none-any.whl: ecodev_front/layouts/app_layout.py <==
"""
Base app component, utilising dmc.AppShell.
"""
import dash
import dash_mantine_components as dmc
from dash import dcc

from ecodev_front.ids import FOOTER_ID
from ecodev_front.ids import NAVBAR_ID
from ecodev_front.ids import TOKEN
from ecodev_front.ids import URL


def dash_base_layout(stores: list[tuple[str, str]],
                     colors: dict[str, list[str]] | None = None) -> dmc.MantineProvider:
    """
    Returns a base layout for any Dash application

    Parameters:
      - stores: A list of tuple (store_name/id, and dcc.Store memory type
                (https://dash.plotly.com/dash-core-components/store)).
                The dcc.Store are placed in the root of the app, to ensure that they are accessible.
      - colors: A dictionary of color pallet name (key) and list of color values from
                https://www.dash-mantine-components.com/components/mantineprovider#custom-colors
    """
    return dmc.MantineProvider(
        forceColorScheme='light',
        theme={'colors': colors} if colors else None,
        children=dmc.AppShell(
            [
                dcc.Location(id=URL, refresh=True),
                dcc.Store(id=TOKEN, data={TOKEN: None}, storage_type='local'),
                *[dcc.Store(id=store_id, storage_type=storage_type)
                  for store_id, storage_type in stores],
                dmc.AppShellHeader(id=NAVBAR_ID, children=[], style={
                                   'background-color': '#0066A1'}, zIndex=100),
                dmc.AppShellMain(dash.page_container, style={'margin-top': '2%'}),
                dmc.AppShellFooter(id=FOOTER_ID, children=[], zIndex=100),
            ],
            style={'padding-inline': '0px', 'background-color': '#f2f2f2'},
            header={'height': 55},
            footer={'height': 40},
        )
    )
